@@ -9,6 +9,7 @@ sample.interval=NA)
 	if (length(p) == 1) # special case
 		p = rep(p, length(S))
 	data <- list(salinity=S, temperature=T, pressure=p, sigma=sw.sigma(S, T, p))
+	processing.log <- list(time=c(Sys.time()), action=c("created by as.CTD()"))
 	res <- list(header=header,
 	      		filename=filename,
               	ship=ship,
@@ -27,6 +28,7 @@ sample.interval=NA)
               	recovery=recovery,
               	water.depth=water.depth,
               	sample.interval=sample.interval,
+				processing.log=processing.log,
               	data=data);
   	class(res) <- "ctd"
 	res
